import functools
from asyncio import Semaphore
from inspect import iscoroutinefunction
from typing import Any

from blinker import Signal
from blinker import signal as get_signal
from httpx import QueryParams
from tenacity import (
    AsyncRetrying,
    Future,
    RetryCallState,
    stop_after_attempt,
    wait_fixed,
    wait_random,
)

from hssp.exception.exception import RequestException, RequestStateException
from hssp.logger.log import hssp_logger
from hssp.models.net import ProxyModel, RequestModel
from hssp.network.downloader import HttpxDownloader, RequestsDownloader
from hssp.network.downloader.base import DownloaderBase
from hssp.network.response import Response
from hssp.settings.settings import settings


class Net:
    def __init__(
        self,
        downloader_cls: type[DownloaderBase] = HttpxDownloader,
        sem: Semaphore = None,
    ):
        """
        Args:
            downloader_cls: 使用的下载器
            sem: 信号量，控制并发
        """
        self._downloader = downloader_cls(sem, settings.headers, settings.cookies)
        self.logger = hssp_logger.getChild("net")

        if downloader_cls.__name__ == RequestsDownloader.__name__:
            self.logger.warning("不建议使用request下载器，无法发挥异步的性能")

        # net id
        self_id = id(self)

        # 请求重试信号
        self.request_retry_signal = get_signal(f"request_retry##{self_id}")
        # 请求之前信号
        self.request_before_signal = get_signal(f"request_before##{self_id}")
        # 响应之后信号
        self.response_after_signal = get_signal(f"response_signal##{self_id}")

    def get_cookies(self):
        """
        获取cookies
        Returns:

        """
        return self._downloader.cookies

    async def close(self):
        """
        关闭
        Returns:

        """
        await self._downloader.close()

    async def _retry_handler(self, req_data: RequestModel, retry_state: RetryCallState):
        """
        处理重试之后和重试失败
        Args:
            req_data: 请求数据
            retry_state: 重试状态

        Returns:

        """
        outcome: Future = retry_state.outcome
        attempt_number = retry_state.attempt_number
        exception = outcome.exception()
        exception_type = type(exception).__name__
        exception_msg = list(exception.args)

        # 执行重试中间件
        async for _ in self._send_signal(self.request_retry_signal, exception):
            ...

        if isinstance(exception, RequestStateException):
            exception_msg = f"响应状态:{exception.code} 不在 200 ~ 299 范围内"

        log_msg = (
            f"[{req_data.method}] {req_data.url} "
            f"使用代理：{req_data.proxy} 发生异常: [{exception_type}]: {exception_msg}"
        )

        if attempt_number == req_data.retrys_count:
            self.logger.error(f"{log_msg} {attempt_number}次重试全部失败")
            raise RequestException(exception_type, exception_msg)

        self.logger.error(f"{log_msg} 第{attempt_number}次重试")

    async def _send_signal(self, signal: Signal, *args, **kwargs):
        """
        发送信号
        Args:
            signal: 信号
            *args: 位置参数
            **kwargs: 键值参数

        Returns:

        """
        for receiver in signal.receivers_for(None):
            if iscoroutinefunction(receiver):
                result = await receiver(*args, **kwargs)
            else:
                result = receiver(*args, **kwargs)

            yield receiver, result

    async def _request(self, data: RequestModel) -> Response:
        """
        使用下载器发起异步请求
        Args:
            data: 请求数据

        Returns:
            返回响应
        """
        # 执行请求中间件
        async for _receiver, result in self._send_signal(self.request_before_signal, data):
            if result and isinstance(result, RequestModel):
                data = result
            if result and isinstance(result, Response):
                return result

        self.logger.info(
            f"[{data.method}] {data.url} "
            f"proxy: {data.proxy} "
            f"params: {data.url_params} "
            f"json_data: {data.json_data} "
            f"form_data: {data.form_data} "
            f"cookies: {data.cookies} "
            f"client_cookies: {self.get_cookies()}"
        )

        resp = await self._downloader.download(data)

        # 执行响应中间件
        async for _receiver, result in self._send_signal(self.response_after_signal, resp):
            if result and isinstance(result, Response):
                return result

        return resp

    def _set_default_request(self, data: RequestModel):
        """
        使用设置里面的全局设置对情求数据进行设置
        Args:
            data: 情求数据

        Returns:

        """
        if data.user_agent is None:
            data.user_agent = settings.user_agent

        if data.headers is None:
            data.headers = settings.headers or {}

        if data.cookies is None:
            data.cookies = settings.cookies

        if data.timeout is None:
            data.timeout = settings.timeout

        if data.proxy is None:
            data.proxy = settings.proxy

        if data.retrys_count is None:
            data.retrys_count = settings.retrys_count

        if data.retrys_delay is None:
            data.retrys_delay = settings.retrys_delay

    async def request(self, data: RequestModel) -> Response:
        """
        发起异步请求
        Args:
            data: 请求参数

        Returns:

        """
        self._set_default_request(data)

        if data.proxy:
            self._downloader.set_proxy(data.proxy)

        # 更新UA
        if data.user_agent:
            data.headers.update({"User-Agent": data.user_agent})

        # 处理 POST form的数据
        # 有些情况form数据的key是相同的，而且还要求顺序，这时使用dict就无法实现
        # 这里是把form数据手动转为经过编码的字符串类型
        if data.form_data and isinstance(data.form_data, list | dict):
            form_data = QueryParams(data.form_data).__str__()
            data.form_data = form_data
            data.headers["Content-Type"] = "application/x-www-form-urlencoded"

        if data.retrys_count < 1:
            return await self._request(data)

        # 设置重试的等候时间
        wait = wait_fixed(data.retrys_delay) + wait_random(0.1, 1) if data.retrys_delay else wait_fixed(0)

        # 异步重试
        retry_resp = AsyncRetrying(
            stop=stop_after_attempt(data.retrys_count),
            after=functools.partial(self._retry_handler, data),
            retry_error_callback=functools.partial(self._retry_handler, data),
            wait=wait,
        )

        return await retry_resp.wraps(functools.partial(self._request, data))()

    async def get(
        self,
        url: str,
        params: dict = None,
        user_agent: str = None,
        headers: dict = None,
        cookies: dict = None,
        timeout: float = None,
        proxy: ProxyModel | str | None = None,
        request_data: RequestModel = None,
    ) -> Response:
        """
        发起GET请求
        Args:
            url: 地址
            params: url参数
            user_agent: ua
            headers: 请求头
            cookies: cookies
            timeout: 超时时间
            proxy: 代理设置
            request_data: 其他的请求参数

        Returns:

        """
        request_data = request_data or RequestModel(url=url, method="GET")
        request_data.url = url
        request_data.method = "GET"
        request_data.url_params = params
        request_data.user_agent = user_agent
        request_data.headers = headers
        request_data.cookies = cookies
        request_data.timeout = timeout
        request_data.proxy = proxy

        return await self.request(request_data)

    async def post(
        self,
        url: str,
        params: dict = None,
        json_data: dict = None,
        form_data: dict[str, Any] | list[tuple[str]] | None = None,
        user_agent: str = None,
        headers: dict = None,
        cookies: dict = None,
        timeout: float = None,
        proxy: ProxyModel | str | None = None,
        request_data: RequestModel = None,
    ) -> Response:
        """
        发起GET请求
        Args:
            url: 地址
            params: url参数
            json_data:
            form_data:
            user_agent: ua
            headers: 请求头
            cookies: cookies
            timeout: 超时时间
            proxy: 代理设置
            request_data: 其他的请求参数

        Returns:

        """
        request_data = request_data or RequestModel(url=url, method="POST")
        request_data.url = url
        request_data.method = "POST"
        request_data.url_params = params
        request_data.user_agent = user_agent
        request_data.headers = headers
        request_data.cookies = cookies
        request_data.timeout = timeout
        request_data.json_data = json_data
        request_data.form_data = form_data
        request_data.proxy = proxy

        return await self.request(request_data)



from asyncio import Semaphore
from json import JSONDecodeError

from httpx import AsyncClient

from hssp.exception.exception import RequestStateException
from hssp.models.net import ProxyModel, RequestModel
from hssp.network.downloader.base import DownloaderBase
from hssp.network.response import Response


class HttpxDownloader(DownloaderBase):
    def __init__(self, sem: Semaphore, headers: dict = None, cookies=None):
        super().__init__(sem, headers, cookies)

        self.client = AsyncClient(
            verify=False,
            http2=True,
            headers=self._default_headers,
            cookies=self._default_cookies,
        )

    async def close(self):
        await self.client.aclose()

    @property
    def cookies(self):
        return {cookie.name: cookie.value for cookie in self.client.cookies.jar}

    def set_proxy(self, proxy: ProxyModel | str):
        proxy_data = {}
        if isinstance(proxy, ProxyModel):
            if proxy.http:
                proxy_data["http://"] = proxy.http
            if proxy.https:
                proxy_data["https://"] = proxy.https
        elif isinstance(proxy, str):
            proxy_data["http://"] = proxy
            proxy_data["https://"] = proxy

        proxy_data = proxy_data or None
        self.client = AsyncClient(
            headers=self.client.headers, cookies=self.client.cookies, proxies=proxy_data, verify=False
        )

    async def _download(self, request_data: RequestModel) -> Response:
        request = self.client.build_request(
            request_data.method,
            request_data.url,
            headers=request_data.headers,
            timeout=request_data.timeout,
            cookies=request_data.cookies,
            params=request_data.url_params,
            data=request_data.form_data,
            json=request_data.json_data,
        )
        response = await self.client.send(request, follow_redirects=True)
        if not response.is_success:
            raise RequestStateException(code=response.status_code)

        try:
            json_data = response.json()
        except (JSONDecodeError, UnicodeDecodeError):
            json_data = None

        # 图片等二进制数据无法解码的，直接返回空字符串
        try:
            text_data = response.text
        except UnicodeDecodeError:
            text_data = ""

        resp_cookies = {cookie.name: cookie.value for cookie in response.cookies.jar}
        return Response(
            url=response.url.__str__(),
            status_code=response.status_code,
            headers=response.headers,
            cookies=resp_cookies,
            client_cookies=self.cookies,
            content=response.content,
            text=text_data,
            json=json_data,
            request_data=request_data,
        )



import secrets
import string


def rand_str(length: int, style: str | None = None) -> str:
    """
    获取固定长度的随机字符串
    Args:
        length: 随机字符串的长度
        style: 随机字符的格式，默认为大写字母+小写字母+数字

    Returns:
        生成的随机字符串
    """
    style = style if style else string.digits + string.ascii_letters
    return "".join(secrets.choice(style) for _ in range(length))


def random_1():
    """
    返回0-1之间的随机数
    Returns:

    """
    return secrets.randbelow(10**6) / 10**6



from hssp.network.downloader.aiohttp import AiohttpDownloader
from hssp.network.downloader.curl_cffi import CurlCffiDownloader
from hssp.network.downloader.httpx import HttpxDownloader
from hssp.network.downloader.requests import RequestsDownloader



import asyncio

from hssp import Net
from hssp.logger.log import Logger, hssp_logger
from hssp.models.net import RequestModel
from hssp.network.downloader import HttpxDownloader
from hssp.network.response import Response


def request_retry(exception):
    logger.info(f"请求报错了:{exception}。正在重试")


async def request_before(request_data: RequestModel):
    logger.info(f"请求之前打印：{request_data}")
    request_data.url_params = {"a": 1}
    return request_data


def request_before_2(request_data: RequestModel):
    logger.info(f"请求之前打印：{request_data}")
    request_data.url_params = {"a": 1, "b": 2}
    return request_data


async def response_after(response_data: Response):
    logger.info(f"响应之后打印：{response_data.request_data} {response_data}")


def response_after_2(response: Response):
    logger.info(f"响应之后打印：{response.request_data} {response}")
    response.cookies = {"aaaa": 1243}
    return response


async def main():
    net = Net(HttpxDownloader)
    net.request_retry_signal.connect(request_retry)
    net.request_before_signal.connect(request_before)
    net.request_before_signal.connect(request_before_2)
    net.response_after_signal.connect(response_after)
    net.response_after_signal.connect(response_after_2)

    async def _send():
        resp = await net.post(
            "https://httpbin.org/post",
            timeout=3,
            form_data={"aa": 111},
            request_data=RequestModel(url="", retrys_count=0),
        )
        logger.info(
            "\n"
            f"情求头：{resp.request_data.headers}\n"
            f"响应body：{resp.content}\n"
            f"响应json：{resp.json}\n"
            f"响应头：{resp.headers}\n"
            f"响应cookies：{resp.cookies}\n"
            f"客户端cookies：{resp.client_cookies}\n"
            f"客户端cookies：{net.get_cookies()}"
        )

    await asyncio.gather(*[_send() for _ in range(1)])

    await net.close()


if __name__ == "__main__":
    Logger.init_logger("test-a.log", ["httpcore.http11", "httpcore.connection", "httpx###DEBUG"])
    logger = hssp_logger.getChild("test")
    asyncio.run(main())



import asyncio
import json
from base64 import b64encode, b64decode
from urllib.parse import quote

from hssp.logger.log import Logger, hssp_logger
from hssp.network import Net
from hssp.network.response import Response
from hssp.utils import crypto


def url_encode_to_bytes(s):
    encoded = quote(s)
    bytes_arr = []
    i = 0
    while i < len(encoded):
        char = encoded[i]
        if char == '%':
            hex_value = encoded[i + 1:i + 3]
            byte = int(hex_value, 16)
            bytes_arr.append(byte)
            i += 3
        else:
            bytes_arr.append(ord(char))
            i += 1
    return bytes(bytes_arr)


def decrypt_resp(response_data: Response):
    """
    解密响应数据
    Args:
        response_data: 响应数据

    Returns:

    """
    data = response_data.json.get('data')
    key_string = 'vEukA&w15z4VAD3kAY#fkL#rBnU!WDhN'
    prefix_length = 12
    data_byte = b64decode(data)

    data_prefix = data_byte[:prefix_length]
    key_string_encode = url_encode_to_bytes(key_string) + data_prefix
    u = len(key_string_encode) // 2

    hash_value = crypto.sha256_hash(key_string_encode, "bytes")[8:8 + 16]

    g = hash_value + key_string_encode[:u]
    y = crypto.sha256_hash(g, "bytes")

    b = key_string_encode[22:44] + hash_value
    e = crypto.sha256_hash(b, "bytes")

    key = y[:8] + e[8: 8 + 16] + y[8 + 16:8 + 16 + 24]
    iv = e[:4] + y[12:12 + 8] + e[-4:]

    data = crypto.decrypt_aes_256_cbc_pad7(data_byte[prefix_length:], key, iv)
    response_data.json['data'] = json.loads(data)


async def main():
    category = {
        17847: "萝莉少女-娇喘连连易推倒",
        23042: "真实破处",
        17972: "猎奇请进",
        17860: "麻豆传媒",
    }

    net = Net()
    net.response_after_signal.connect(decrypt_resp)
    resp = await net.post(
        "https://h5dfsg.anwangjd1.com/api/app/media/topic/details",
        headers={
            'authorization': 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhdWQiOiJwdWJsaWMiLCJleHAiOjE3Mjc0OTkzOTgsImlzc3VlciI6ImNvbS5idXR0ZXJmbHkiLCJzdWIiOiJhc2lnbiIsInVzZXJJZCI6Nzc2NDczNX0.c6I3SzQemjhgt-FTAh1XDto5Jwi6mnBEPXU6SWFz0OQ'
        },
        json_data={"id": 17860, "mediaType": 1, "pageNum": 1, "pageSize": 50, "sort": 0}
    )
    logger.info(f"data: {resp.json}")
    await net.close()


if __name__ == '__main__':
    Logger.init_logger()
    logger = hssp_logger.getChild("极乐禁地")
    asyncio.run(main())



from abc import ABC, abstractmethod
from asyncio import Semaphore

from hssp.models.net import ProxyModel, RequestModel
from hssp.network.response import Response


class DownloaderBase(ABC):
    def __init__(self, sem: Semaphore, headers: dict = None, cookies=None):
        """
        Args:
            sem: 信号量，控制并发
        """
        self.sem = sem
        self._default_headers = headers or {}
        self._default_cookies = cookies or {}

    async def download(self, request: RequestModel) -> Response:
        """
        下载方法，受信号量控制
        Args:
            request:

        Returns:

        """
        if self.sem:
            async with self.sem:
                return await self._download(request)
        else:
            return await self._download(request)

    @property
    @abstractmethod
    def cookies(self):
        """
        获取cookies
        Returns:

        """
        raise NotImplementedError

    @abstractmethod
    def set_proxy(self, proxy: ProxyModel):
        """
        设置代理，有些客户端不可以在请求时设置代理，所以提供一个入口
        Args:
            proxy: 代理

        Returns:

        """
        raise NotImplementedError

    @abstractmethod
    async def _download(self, request: RequestModel) -> Response:
        """
        下载，子类实现具体的请求方法
        Args:
            request: 请求模型

        Returns:
            放回响应
        """
        raise NotImplementedError

    @abstractmethod
    async def close(self):
        """
        关闭下载器
        Returns:

        """
        raise NotImplementedError


class RenderDownloader(DownloaderBase, ABC):
    def put_back(self, driver):
        """
        释放浏览器对象
        """
        pass

    def close(self):
        """
        关闭浏览器
        """
        pass

    def close_all(self):
        """
        关闭所有浏览器
        """
        pass



import logging
import sys
from pathlib import Path

from loguru import logger

# noinspection PyProtectedMember
from loguru._defaults import env

from hssp.logger.handler import InterceptHandler
from hssp.settings.settings import settings
from hssp.utils.classes import SingletonMeta


class Logger(metaclass=SingletonMeta):
    @classmethod
    def init_logger(
        cls,
        log_file: str | Path | None = None,
        hide_types: list[str] | None = None,
    ):
        log_format = env(
            "LOGURU_FORMAT",
            str,
            "<green>{time:YYYY-MM-DD HH:mm:ss.SSS}</green> | "
            "<red>{extra[type]: <10}</red> | "
            "<level>{level: <8}</level> | "
            "<cyan>{name}</cyan>:<cyan>{function}</cyan>:<cyan>{line}</cyan> - <level>{message}</level>",
        )
        logger.remove()
        logger.add(sys.stdout, colorize=True, format=log_format)

        logfile = Path(log_file) if isinstance(log_file, str) else Path
        logger.add(logfile, backtrace=True, format=log_format)

        logging.basicConfig(handlers=[InterceptHandler(hide_types)], level=settings.log_mode, force=True)

    @classmethod
    def get_logger(cls, name: str):
        """
        获取一个带类型的日志
        Args:
            name: 日志类型

        Returns:

        """

        name = name.replace(".", " ☞ ")
        return logging.getLogger(name)


hssp_logger = Logger.get_logger("hssp")



import logging
import logging.config
import sys
from types import FrameType

from loguru import logger


class InterceptHandler(logging.StreamHandler):
    def __init__(self, hide_types: list[str] | None = None):
        super().__init__()
        self.hide_types = [
            hide_type if "###" in hide_type else f"{hide_type}###ALL" for hide_type in hide_types or [] if hide_type
        ]

    def emit(self, record: logging.LogRecord):
        # Get corresponding Loguru level if it exists
        try:
            level: int | str = logger.level(record.levelname).name
        except ValueError:
            level = record.levelno

        # Find caller from where originated the logged message.
        # noinspection PyProtectedMember,PyUnresolvedReferences
        frame: FrameType | None = sys._getframe(6)
        depth: int = 6
        while frame and frame.f_code.co_filename == logging.__file__:
            frame = frame.f_back
            depth += 1

        fmt = "%(message)s"
        formatter = logging.Formatter(fmt=fmt)
        msg = formatter.format(record)

        # 按照类型去过滤掉不想看到的日志
        record_name = f"{record.name.strip()}###{record.levelname}"
        for hide_type in self.hide_types:
            hide_type_name, hide_type_level = hide_type.split("###")
            if not record_name.startswith(hide_type_name):
                continue
            if hide_type_level == "ALL" or hide_type == record_name:
                return

        record.name = record.name.replace(".", " ☞ ").strip()
        etxra_data = {"type": record.name}
        logger.bind(**etxra_data).opt(depth=depth, exception=record.exc_info).log(level, msg)



from typing import Any

from pydantic import BaseModel, Field


class ProxyModel(BaseModel):
    http: str = ""
    https: str = ""


class RequestModel(BaseModel):
    url: str = Field(title="请求的地址")
    method: str = Field(title="请求的方法", default="GET")
    url_params: dict[str, Any] | None = Field(title="请求的url数据", default=None)
    form_data: dict[str, Any] | list[tuple[str]] | str | None = Field(title="form请求的数据", default=None)
    json_data: dict[str, Any] | None = Field(title="json请求的数据", default=None)
    # 下面这些属性, 默认值为设置中的值
    user_agent: str | None = Field(title="请求UA", default=None)
    headers: dict[str, Any] | None = Field(title="请求头", default=None)
    cookies: dict[str, Any] | None = Field(title="传递的cookies", default=None)
    timeout: int | None = Field(title="请求超时时间", default=None)
    proxy: ProxyModel | str | None = Field(title="代理设置", default=None)
    retrys_count: int | None = Field(title="重试次数", default=None)
    retrys_delay: int | None = Field(title="重试延时", default=None)



from typing import Any

from pydantic import BaseModel

from hssp.models.config import LogMode
from hssp.settings.setting_base import SettingsBase


class ProxyModel(BaseModel):
    http: str = ""
    https: str = ""


class Settings(SettingsBase):
    """
    设置
    """

    # 日志模式
    log_mode: LogMode = LogMode.INFO

    # 默认并发量
    concurrency: int = 32

    # 请求UA
    user_agent: str | None = None

    # 默认请求头
    headers: dict[str, Any] | None = None

    # 默认的cookies
    cookies: dict[str, Any] | None = None

    # 默认的请求超时时间
    timeout: int | None = 20

    # 默认的代理设置
    proxy: ProxyModel | str | None = None

    # 默认的重试次数
    retrys_count: int = 15

    # 默认每次重视之间的延迟，单位是秒
    retrys_delay: int = 0


settings = Settings()



from parsel import Selector as BaseSelector
from parsel import SelectorList as BaseSelectorList


class SelectorList(BaseSelectorList):
    domain: str = ""

    def proc_result(self, value, domain, is_url):
        if is_url and domain and value.startswith("/"):
            value = domain + value
        if isinstance(value, str):
            value = value.strip()
        return value

    def getall(self, is_url=False):
        result = super().getall()
        return [self.proc_result(x, domain=self.domain, is_url=is_url) for x in result]

    def get(self, default=None, is_url=False):
        result = super().get(default=default)
        result = self.proc_result(result, self.domain, is_url)
        return result


class Selector(BaseSelector):
    selectorlist_cls = SelectorList

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def css(self, query, domain=None):
        result = super().css(query)
        result.domain = domain
        return result

    def xpath(self, query, namespaces=None, domain=None, **kwargs):
        result = super().xpath(query, namespaces=namespaces, **kwargs)
        result.domain = domain
        return result



import asyncio

from hssp.logger.log import Logger
from hssp import Net


async def main():
    net = Net()
    url = "http://5yqmu9zt.z88gvbz02msvjwe2.ph.faypb.cn/api/v1/app/votes?stage_code=BM8ffv5we6"
    headers = {
        "authorization": "Bearer eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJpc3MiOiJodHRwOlwvXC81eXFtdTl6dC56ODhndmJ6MDJtc3Zqd2UyLnBoLmZheXBiLmNuXC9hcHBcL2F1dGhcLzk1ODk0MDciLCJpYXQiOjE3Mjg5NjQzMjUsImV4cCI6MTczMTU1NjMyNSwibmJmIjoxNzI4OTY0MzI1LCJqdGkiOiJXOEdSeWVla0FFbXA0OEZvIiwic3ViIjo5NTg5NDA3LCJwcnYiOiI1ODkzZWZlMTc4ZmJiNGVhZmI5ODRkMzE5NjA3N2MzNDQxMjI0MzYzIiwiYXBwaWQiOiJ3eGJiMjA2NzY1YjI0Y2UxZDkiLCJndWFyZCI6ImFwcCJ9.3RTgBecTI2tHwAVo5jcYHQbblWG-2gqIfHbpU83dw48",
        "origin": "http://5yqmu9zt.z88gvbz02msvjwe2.ph.faypb.cn",
        "host": "5yqmu9zt.z88gvbz02msvjwe2.ph.faypb.cn",
        "user-agent": "Mozilla/5.0 (Linux; Android 14; V2172A Build/UP1A.231005.007; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/126.0.6478.188 Mobile Safari/537.36 XWEB/1260183 MMWEBSDK/20240501 MMWEBID/172 MicroMessenger/8.0.50.2701(0x2800325B) WeChat/arm64 Weixin NetType/WIFI Language/zh_CN ABI/arm64"
    }
    data = {
        "player_ids": ["453706"]
    }
    params = {
        "stage_code": "BM8ffv5we6"
    }

    proxy = 'http://a01c69ff:6ff0572c7455417fa81cb2577ca817ef@cellular.proxy.acedata.cloud:30000'

    resp = await net.post(url, headers=headers, json_data=data, params=params, proxy=proxy)
    logger.info(resp.json)
    await net.close()


if __name__ == '__main__':
    Logger.init_logger()
    logger = Logger.get_logger("test")
    asyncio.run(main())



from asyncio import Semaphore

from aiohttp import ClientSession, ClientTimeout, ContentTypeError, TCPConnector

from hssp.exception.exception import RequestStateException
from hssp.models.net import ProxyModel, RequestModel
from hssp.network.downloader.base import DownloaderBase
from hssp.network.response import Response


class AiohttpDownloader(DownloaderBase):
    def __init__(self, sem: Semaphore, headers: dict = None, cookies=None):
        super().__init__(sem, headers, cookies)

        self.client = ClientSession(
            headers=self._default_headers,
            cookies=self._default_cookies,
            connector=TCPConnector(ssl=False),
            trust_env=True,
        )

    async def close(self):
        await self.client.close()

    def set_proxy(self, proxy: ProxyModel | str): ...

    @property
    def cookies(self):
        return {cookie.key: cookie.value for cookie in self.client.cookie_jar}

    async def _download(self, request_data: RequestModel) -> Response:
        if isinstance(request_data.proxy, ProxyModel):
            proxy = request_data.proxy.https or request_data.proxy.http
        else:
            proxy = request_data.proxy

        timeout = ClientTimeout(total=request_data.timeout)
        response = await self.client.request(
            method=request_data.method,
            url=request_data.url,
            params=request_data.url_params,
            data=request_data.form_data,
            json=request_data.json_data,
            cookies=request_data.cookies,
            headers=request_data.headers,
            proxy=proxy,
            timeout=timeout,
        )

        if not response.ok:
            raise RequestStateException(code=response.status)

        resp_headers = dict(response.headers)
        resp_content = await response.read()

        # 图片等二进制数据无法解码的，直接返回空字符串
        try:
            resp_text = await response.text()
        except UnicodeDecodeError:
            resp_text = ""

        resp_cookies = {name: cookie.value for name, cookie in response.cookies.items()}
        try:
            resp_json = await response.json()
        except (ContentTypeError, UnicodeDecodeError):
            resp_json = None

        return Response(
            url=response.url.__str__(),
            status_code=response.status,
            headers=resp_headers,
            cookies=resp_cookies,
            client_cookies=self.cookies,
            content=resp_content,
            text=resp_text,
            json=resp_json,
            request_data=request_data,
        )
